==> everycomp-1.20-2.8.1-forge-sources.jar: net/mehvahdjukaar/every_compat/modules/forge/more/MoreCraftingTablesForForgeModule.java <==
package net.mehvahdjukaar.every_compat.modules.forge.more;

import com.duart.mctb.blocks.CraftingBlock;
import net.mehvahdjukaar.every_compat.EveryCompat;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodTypeRegistry;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.core.registries.Registries;
import net.minecraft.resources.ResourceKey;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.tags.BlockTags;
import net.minecraft.world.item.CreativeModeTabs;
import net.minecraft.world.level.block.Block;

import java.util.List;

// SUPPORT: v5.1.2+
// NOTE: More Crafting Table for Forge! is developed by Duart And is FORGE only
public class MoreCraftingTablesForForgeModule extends SimpleModule {

    public final SimpleEntrySet<WoodType, Block> craftingTable;

    public MoreCraftingTablesForForgeModule(String modId) {
        super(modId, "mctb");
        var tab = CreativeModeTabs.f_256791_;

        craftingTable = SimpleEntrySet.builder(WoodType.class, "crafting_table",
                        getModBlock("spruce_crafting_table"),
                        () -> WoodTypeRegistry.getValue(new ResourceLocation("spruce")),
                        w -> new CraftingBlock(Utils.copyPropertySafe(w.planks)))
                //TEXTURE: texture is oak_craftng_table's texture
                .addTextureM(EveryCompat.res("block/spruce_crafting_table_front"), EveryCompat.res("block/mctb/spruce_crafting_table_front_m"))
                .addTextureM(EveryCompat.res("block/spruce_crafting_table_side"), EveryCompat.res("block/mctb/spruce_crafting_table_side_m"))
                .addTextureM(EveryCompat.res("block/spruce_crafting_table_top"), EveryCompat.res("block/mctb/spruce_crafting_table_top_m"))
                .addTag(new ResourceLocation("forge:workbenches"), Registries.f_256747_)
                .addTag(new ResourceLocation("forge:workbench"), Registries.f_256747_)
                .addTag(new ResourceLocation("forge:workbenches"), Registries.f_256913_)
                .addTag(new ResourceLocation("forge:workbench"), Registries.f_256913_)
                .addTag(new ResourceLocation("charm:crafting_table"), Registries.f_256913_)
                .addTag(modRes("revertable_workbench"), Registries.f_256913_)
                .addTag(BlockTags.f_144280_, Registries.f_256747_)
                .setTabKey(tab)
                .defaultRecipe()
                .build();

        this.addEntry(craftingTable);
    }

    @Override
    public List<String> getAlreadySupportedMods() {
        return List.of(
                "biomesoplenty", "quark", "ad_astra",
                "naturesaura", "undergarden", "twilightforest",
                "regions_unexplored"
        );

    }
}

==> everycomp-1.20-2.9.8-forge-sources.jar: net/mehvahdjukaar/every_compat/modules/forge/more/MoreCraftingTablesForForgeModule.java <==
package net.mehvahdjukaar.every_compat.modules.forge.more;

import com.duart.mctb.blocks.CraftingBlock;
import net.mehvahdjukaar.every_compat.EveryCompat;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.moonlight.api.set.wood.VanillaWoodTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.core.registries.Registries;
import net.minecraft.resources.ResourceKey;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.tags.BlockTags;
import net.minecraft.world.item.CreativeModeTabs;
import net.minecraft.world.level.block.Block;

import java.util.List;

// SUPPORT: v5.1.2+
// NOTE: More Crafting Table for Forge! is developed by Duart And is FORGE only
public class MoreCraftingTablesForForgeModule extends SimpleModule {

    public final SimpleEntrySet<WoodType, Block> craftingTable;

    public MoreCraftingTablesForForgeModule(String modId) {
        super(modId, "mctb");
        var tab = CreativeModeTabs.f_256791_;

        craftingTable = SimpleEntrySet.builder(WoodType.class, "crafting_table",
                        getModBlock("spruce_crafting_table"),
                        () -> VanillaWoodTypes.SPRUCE,
                        w -> new CraftingBlock(Utils.copyPropertySafe(w.planks)))
                //TEXTURE: texture is oak_craftng_table's texture
                .addTextureM(EveryCompat.res("block/spruce_crafting_table_front"), EveryCompat.res("block/mctb/spruce_crafting_table_front_m"))
                .addTextureM(EveryCompat.res("block/spruce_crafting_table_side"), EveryCompat.res("block/mctb/spruce_crafting_table_side_m"))
                .addTextureM(EveryCompat.res("block/spruce_crafting_table_top"), EveryCompat.res("block/mctb/spruce_crafting_table_top_m"))
                .addTag(new ResourceLocation("forge:workbenches"), Registries.f_256747_)
                .addTag(new ResourceLocation("forge:workbench"), Registries.f_256747_)
                .addTag(new ResourceLocation("forge:workbenches"), Registries.f_256913_)
                .addTag(new ResourceLocation("forge:workbench"), Registries.f_256913_)
                .addTag(new ResourceLocation("charm:crafting_table"), Registries.f_256913_)
                .addTag(modRes("revertable_workbench"), Registries.f_256913_)
                .addTag(BlockTags.f_144280_, Registries.f_256747_)
                .setTabKey(tab)
                .defaultRecipe()
                .build();

        this.addEntry(craftingTable);
    }

    @Override
    public List<String> getAlreadySupportedMods() {
        return List.of(
                "biomesoplenty", "quark", "ad_astra",
                "naturesaura", "undergarden", "twilightforest",
                "regions_unexplored"
        );

    }
}
